@@ -28,8 +28,8 @@ const _ = imports.gettext.gettext;
 // Import versions go here
 imports.gi.versions.GdPrivate = '1.0';
 imports.gi.versions.Gd = '1.0';
-imports.gi.versions.Tracker = '0.16';
-imports.gi.versions.TrackerMiner = '0.16';
+imports.gi.versions.Tracker = '0.18';
+imports.gi.versions.TrackerMiner = '0.18';
 imports.gi.versions.EvinceDocument = '3.0';
 imports.gi.versions.Goa = '1.0';
 imports.gi.versions.WebKit = '3.0';
@@ -160,9 +160,7 @@ const Application = new Lang.Class({
     _viewAsCreateHook: function(action) {
         settings.connect('changed::view-as', Lang.bind(this,
             function() {
-                let state = settings.get_value('view-as');
-                if (state.get_string()[0] != action.state.get_string()[0])
-                    action.state = state;
+                action.state = settings.get_value('view-as');
             }));
     },
 
@@ -189,8 +187,7 @@ const Application = new Lang.Class({
     },
 
     _onActionViewAs: function(action, parameter) {
-        if (parameter.get_string()[0] != action.state.get_string()[0])
-            settings.set_value('view-as', parameter);
+        settings.set_value('view-as', parameter);
     },
 
     _onActionOpenCurrent: function() {
@@ -427,7 +424,8 @@ const Application = new Lang.Class({
             { name: 'open-current',
               callback: this._onActionOpenCurrent,
               window_mode: WindowMode.WindowMode.PREVIEW },
-            { name: 'edit-current' },
+            { name: 'edit-current',
+              window_mode: WindowMode.WindowMode.PREVIEW },
             { name: 'view-current',
               window_mode: WindowMode.WindowMode.EDIT },
             { name: 'present-current',
@@ -520,7 +518,6 @@ const Application = new Lang.Class({
         // clean up signals
         changeMonitor.disconnectAll();
         documentManager.disconnectAll();
-        offsetController.disconnectAll();
         trackerController.disconnectAll();
         selectionController.disconnectAll();
         modeController.disconnectAll();
