@@ -67,9 +67,6 @@ const Searchbar = new Lang.Class({
                 if (keyval == Gdk.KEY_Escape) {
                     Application.application.change_action_state('search', GLib.Variant.new('b', false));
                     return true;
-                } else if (keyval == Gdk.KEY_Return) {
-                    this.emit('activate-result');
-                    return true;
                 }
 
                 return false;
@@ -204,7 +201,6 @@ const Searchbar = new Lang.Class({
         this._searchEntry.set_text('');
     }
 });
-Signals.addSignalMethods(Searchbar.prototype);
 
 const Dropdown = new Lang.Class({
     Name: 'Dropdown',
@@ -331,7 +327,7 @@ const OverviewSearchbar = new Lang.Class({
     },
 
     entryChanged: function() {
-        let currentText = this._searchEntry.get_text();
+        let currentText = this._searchEntry.get_text().toLowerCase();
 
         Application.searchController.disconnect(this._searchChangedId);
         Application.searchController.setString(currentText);
