@@ -90,7 +90,7 @@ function _createThumbnailIcon(uri) {
         if (path)
             return new Gio.FileIcon({ file: Gio.file_new_for_path(path) });
     } catch(e) {
-        log(e);
+        log('Unable to create thumbnail icon: ' + e.message);
     }
     return null;
 }
@@ -149,7 +149,7 @@ const CreateCollectionIconJob = new Lang.Class({
                     cursor = object.query_finish(res);
                     cursor.next_async(null, Lang.bind(this, this._onCursorNext));
                 } catch (e) {
-                    log('Error querying tracker: ' + e);
+                    log('Unable to run CreateCollectionIconJob: ' + e.message);
                     this._hasItemIds();
                 }
             }));
@@ -171,7 +171,7 @@ const CreateCollectionIconJob = new Lang.Class({
             try {
                 pixbuf = info.load_icon();
             } catch(e) {
-                log("Unable to load pixbuf: " + e);
+                log("Unable to load pixbuf: " + e.message);
             }
         } else if (icon instanceof Gio.FileIcon) {
             try {
@@ -179,7 +179,7 @@ const CreateCollectionIconJob = new Lang.Class({
                 pixbuf = GdkPixbuf.Pixbuf.new_from_stream(stream,
                                                           null);
             } catch(e) {
-                log("Unable to load pixbuf: " + e);
+                log("Unable to load pixbuf: " + e.message);
             }
         }
 
@@ -193,7 +193,7 @@ const CreateCollectionIconJob = new Lang.Class({
             valid = cursor.next_finish(res);
         } catch (e) {
             cursor.close();
-            log('Error querying tracker: ' + e);
+            log('Unable to read results of CreateCollectionIconJob: ' + e.message);
 
             this._hasItemIds();
         }
@@ -329,7 +329,7 @@ const FetchIdsJob = new Lang.Class({
                     cursor = object.query_finish(res);
                     cursor.next_async(this._cancellable, Lang.bind(this, this._onCursorNext));
                 } catch (e) {
-                    log('Error querying tracker: ' + e);
+                    log('Unable to run FetchIdsJob: ' + e.message);
                     callback(this._ids);
                 }
             }));
@@ -342,7 +342,7 @@ const FetchIdsJob = new Lang.Class({
             valid = cursor.next_finish(res);
         } catch (e) {
             cursor.close();
-            log('Error querying tracker: ' + e);
+            log('Unable to read results of FetchIdsJob: ' + e.message);
 
             this._callback(this._ids);
         }
